ngff_zarr.zarr_metadata - ngff-zarr
Description: Module Contents: Classes:,, Axis,,, Identity,,, Scale,,, Translation,,, Dataset,,, Metadata,,,,, Functions:,, is_dimension_supported, Helper for string validation,, is_unit_supported, Helper for st...

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.zarr_metadata`

## Module Contents

### Classes

`Axis` |
`Identity` |
`Scale` |
`Translation` |
`Dataset` |
`Metadata` |

### Functions

`is_dimension_supported` | Helper for string validation
`is_unit_supported` | Helper for string validation

### Data

`SupportedDims` |
`SpatialDims` |
`AxesType` |
`SpaceUnits` |
`TimeUnits` |
`Units` |
`supported_dims` |
`space_units` |
`time_units` |
`Transform` |

### API

ngff_zarr.zarr_metadata.SupportedDims

  None

ngff_zarr.zarr_metadata.SpatialDims

  None

ngff_zarr.zarr_metadata.AxesType

  None

ngff_zarr.zarr_metadata.SpaceUnits

  None

ngff_zarr.zarr_metadata.TimeUnits

  None

ngff_zarr.zarr_metadata.Units

  None

ngff_zarr.zarr_metadata.supported_dims

  [‘x’, ‘y’, ‘z’, ‘c’, ‘t’]

ngff_zarr.zarr_metadata.space_units

  [‘angstrom’, ‘attometer’, ‘centimeter’, ‘decimeter’, ‘exameter’, ‘femtometer’, ‘foot’, ‘gigameter’, …

ngff_zarr.zarr_metadata.time_units

  [‘attosecond’, ‘centisecond’, ‘day’, ‘decisecond’, ‘exasecond’, ‘femtosecond’, ‘gigasecond’, ‘hectos…

ngff_zarr.zarr_metadata.is_dimension_supported(dim: str) → bool

  Helper for string validation

ngff_zarr.zarr_metadata.is_unit_supported(unit: str) → bool

  Helper for string validation

class ngff_zarr.zarr_metadata.Axis
  name: ngff_zarr.zarr_metadata.SupportedDims

    None

  type: ngff_zarr.zarr_metadata.AxesType

    None

  unit: Optional[ngff_zarr.zarr_metadata.Units]

    None

class ngff_zarr.zarr_metadata.Identity
  type: str

    ‘identity’

class ngff_zarr.zarr_metadata.Scale
  scale: List[float]

    None

  type: str

    ‘scale’

class ngff_zarr.zarr_metadata.Translation
  translation: List[float]

    None

  type: str

    ‘translation’

ngff_zarr.zarr_metadata.Transform

  None

class ngff_zarr.zarr_metadata.Dataset
  path: str

    None

  coordinateTransformations: List[ngff_zarr.zarr_metadata.Transform]

    None

class ngff_zarr.zarr_metadata.Metadata
  axes: List[ngff_zarr.zarr_metadata.Axis]

    None

  datasets: List[ngff_zarr.zarr_metadata.Dataset]

    None

  coordinateTransformations: Optional[List[ngff_zarr.zarr_metadata.Transform]]

    None

  name: str

    ‘image’

  version: str

    ‘0.4’